/**
        A cash register totals up sales and computes change due.
 */
public class CashRegister
{
	public static final double QUARTER_VALUE = 0.25;
	public static final double DIME_VALUE = 0.1;
	public static final double NICKEL_VALUE = 0.05;
	public static final double PENNY_VALUE = 0.01;

	final int PENNIES_PER_NICKEL = 5;
	final int PENNIES_PER_DIME = 10;
	final int PENNIES_PER_QUARTER = 25;
	final int PENNIES_PER_DOLLAR = 100;

	private double purchase;
	private int totalPurchaseInPennies;
	private double payment;

	/**
           Constructs a cash register with no money in it.
	 */
	public CashRegister()
	{
		purchase = 0;
		payment = 0;
	}
	/**
        Records the purchase price of an item.
        @param amount the price of the purchased item
	 */
	public void recordPurchase(double amount)
	{
		purchase = purchase + amount;
	}

	/**
        Enters the payment received from the customer.
        @param dollars the number of dollars in the payment
        @param quarters the number of quarters in the payment
        @param dimes the number of dimes in the payment
        @param nickels the number of nickels in the payment
        @param pennies the number of pennies in the payment
	 */
	public void enterPayment(int dollars, int quarters, 
			int dimes, int nickels, int pennies)
	{
		payment = dollars + quarters * QUARTER_VALUE + dimes * DIME_VALUE
				+ nickels * NICKEL_VALUE + pennies * PENNY_VALUE;

		// Compute total value in pennies
		totalPurchaseInPennies = dollars * PENNIES_PER_DOLLAR + quarters
				* PENNIES_PER_QUARTER + nickels * PENNIES_PER_NICKEL
				+ dimes * PENNIES_PER_DIME + pennies;
	}
	
	/**
    Computes the change due and resets the machine for the next customer.
    @return the change due to the customer
	 */
	public double giveChange()
	{
		double change = payment - purchase;
		purchase = 0;
		payment = 0;
		return change;
	}
	public void printMinimalCoins() {
		int totalDollars = totalPurchaseInPennies / PENNIES_PER_DOLLAR;
		totalPurchaseInPennies = totalPurchaseInPennies % PENNIES_PER_DOLLAR;
		int totalQuarters = totalPurchaseInPennies / PENNIES_PER_QUARTER;
		totalPurchaseInPennies = totalPurchaseInPennies % PENNIES_PER_QUARTER;
		int totalDimes = totalPurchaseInPennies / PENNIES_PER_DIME;
		totalPurchaseInPennies = totalPurchaseInPennies % PENNIES_PER_DIME;
		int totalNickels = totalPurchaseInPennies / PENNIES_PER_NICKEL;
		totalPurchaseInPennies = totalPurchaseInPennies % PENNIES_PER_NICKEL;
		
		System.out.println("Dollars: " + totalDollars);
		System.out.println("Quarters: " + totalQuarters);
		System.out.println("Dimes: " + totalDimes);
		System.out.println("Nickels: " + totalNickels);
		System.out.println("Pennies: " + totalPurchaseInPennies);
	}
}

